#!/usr/bin/env python
#
# storms documentation build configuration file, created by
# sphinx-quickstart on Fri Jun  9 13:47:02 2017.
#
# This file is execfile()d with the current directory set to its
# containing dir.
#
# Note that not all possible configuration values are present in this
# autogenerated file.
#
# All configuration values have a default; values that are commented out
# serve to show the default.

# If extensions (or modules to document with autodoc) are in another
# directory, add these directories to sys.path here. If the directory is
# relative to the documentation root, use os.path.abspath to make it
# absolute, like shown here.
#
import os
import sys

sys.path.insert(0, os.path.abspath(".."))

# sys.path.insert(0, "../storms")
import os

#
# import sphinx_rtd_theme

import storms


package_path = os.path.abspath("../..")
os.environ["PYTHONPATH"] = ":".join((package_path, os.environ.get("PYTHONPATH", "")))

# -- General configuration ---------------------------------------------

# If your documentation needs a minimal Sphinx version, state it here.
#
# needs_sphinx = '1.0'

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
extensions = [
    "matplotlib.sphinxext.plot_directive",
    "sphinx.ext.intersphinx",
    "sphinx.ext.mathjax",
    "myst_parser",
    "IPython.sphinxext.ipython_directive",
    "IPython.sphinxext.ipython_console_highlighting",
    "sphinx.ext.autodoc",
    "sphinx.ext.autosummary",
    "sphinx.ext.viewcode",
    "numpydoc",
    "nbsphinx",
]

# Add any paths that contain templates here, relative to this directory.
templates_path = ["_templates"]

# The suffix(es) of source filenames.
# You can specify multiple suffix as a list of string:
#
# source_suffix = ['.rst', '.md']
source_suffix = ".rst"

# The master toctree document.
master_doc = "index"

# General information about the project.
project = "storms"
copyright = "2021, Constantine Karos"
author = "Constantine Karos"

# The version info for the project you're documenting, acts as replacement
# for |version| and |release|, also used in various other places throughout
# the built documents.
#
# The short X.Y version.
version = storms.__version__
# The full version, including alpha/beta/rc tags.
release = storms.__version__

# The language for content autogenerated by Sphinx. Refer to documentation
# for a list of supported languages.
#
# This is also used if you do content translation via gettext catalogs.
# Usually you set "language" from the command line for these cases.
language = "en"

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This patterns also effect to html_static_path and html_extra_path
exclude_patterns = [
    "_build",
    "**.ipynb_checkpoints",
    "*/autosummary/*.rst",
    "Thumbs.db",
    ".DS_Store",
]

# The name of the Pygments (syntax highlighting) style to use.
pygments_style = "default"
pygments_dark_style = "dracula"

# If true, `todo` and `todoList` produce output, else they produce nothing.
todo_include_todos = True


# -- Options for HTML output -------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
html_theme = "furo"

html_theme_options = {
    "dark_css_variables": {
        "color-background-primary": "#282A36",
        "color-sidebar-background": "#22212c",
        "color-api-name": "#BD93F9",
        "color-sidebar-link-text--top-level": "#FF79C6",
        # "color-link": "#8BE9FD",
        "color-highlight-on-target": "#BD93F91C",
        "color-toc-item-text--active": "#50FA7B",
    },
    "footer_icons": [
        {
            "name": "GitHub",
            "url": "https://github.com/karosc/storms",
            "html": "",
            "class": "fa-brands fa-github-alt fa-2x",
        },
    ],
}  # end html_theme_options
# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".


html_logo = "storms_logo_with_text.svg"
html_favicon = "favicon.ico"

autosummary_generate = True
numpydoc_show_class_members = False
autodoc_member_order = "bysource"
autodoc_typehints = "none"
autoclass_content = "both"
add_module_names = False

# autodoc_default_options = {
#     'members': 'var1, var2',
#     'member-order': 'bysource',
#     'special-members': '',
#     'undoc-members': True,
#     'exclude-members': '__weakref__'
# }

plot_include_source = True
plot_html_show_source_link = False
plot_html_show_formats = False

html_last_updated_fmt = ""
html_use_index = False
html_domain_indices = False

html_static_path = ["_static"]

html_css_files = [
    "./css/custom.css",
    "https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/fontawesome.min.css",
    "https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/solid.min.css",
    "https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/brands.min.css",
]


#https://github.com/spatialaudio/nbsphinx/issues/128
html_js_files = [
    "js/MathJax.js",
    "js/require.min.js",
    "js/custom.js",
]


# -- Options for HTMLHelp output ---------------------------------------

# If false, no module index is generated.
html_domain_indices = True

# Output file base name for HTML help builder.
htmlhelp_basename = "stormsdoc"


# -- Options for LaTeX output ------------------------------------------

latex_elements = {
    # The paper size ('letterpaper' or 'a4paper').
    #
    "papersize": "letterpaper",
    # The font size ('10pt', '11pt' or '12pt').
    #
    "pointsize": "10pt",
    # Additional stuff for the LaTeX preamble.
    #
    "preamble": "",
    # Latex figure (float) alignment
    #
    # 'figure_align': 'htbp',
}

# Grouping the document tree into LaTeX files. List of tuples
# (source start file, target name, title, author, documentclass
# [howto, manual, or own class]).
latex_documents = [
    (master_doc, "storms.tex", "storms Documentation", "Constantine Karos", "manual"),
]


# -- Options for manual page output ------------------------------------

# One entry per manual page. List of tuples
# (source start file, name, description, authors, manual section).
man_pages = [(master_doc, "storms", "storms Documentation", [author], 1)]


# -- Options for Texinfo output ----------------------------------------

# Grouping the document tree into Texinfo files. List of tuples
# (source start file, target name, title, author,
#  dir menu entry, description, category)
texinfo_documents = [
    (
        master_doc,
        "storms",
        "storms Documentation",
        author,
        "storms",
        "One line description of project.",
        "Miscellaneous",
    ),
]

nbsphinx_execute = "never"

intersphinx_mapping = {
    "numpy": ("https://docs.scipy.org/doc/numpy/", None),
    "python": ("https://docs.python.org/3/", None),
    "pydagogue": ("https://matthew-brett.github.io/pydagogue/", None),
    "matplotlib": ("https://matplotlib.org/", None),
    "scipy": ("https://docs.scipy.org/doc/scipy/reference/", None),
    "pandas": ("https://pandas.pydata.org/pandas-docs/stable/", None),
}


rst_prolog = """
.. role:: python(code)
    :language: python
    :class: highlight
"""

# mathjax_path = "js/MathJax.js"
# nbsphinx_requirejs_path = "https://cdnjs.cloudflare.com/ajax/libs/require.js/2.1.10/require.min.js" 
# nbsphinx_requirejs_options = {
#     "src": "https://cdnjs.cloudflare.com/ajax/libs/require.js/2.1.10/require.min.js",
#     "integrity": "sha512-VCK7oF67GXNc+J7zsu5o57jtxhLA75nSMHGaq8Q8TCOxDj4nMDw5dhQZvm9Cd9RN+3zgcodqbKcRc9gyPP8a2w==",
#     "crossorigin": "anonymous",
# }
